import { adapter } from '@/utils';
import {
  adapterOfFetchEventList,
  adapterOfFetchFieldList,
  adapterOfFetchIndicatorsList,
  adapterOfFetchWorkflowList
} from '@/service/api/event.adapter';
import { backgroundRequest } from '../request';

/** 获取用户列表 */
export const fetchFieldList = async (page: number, page_size: number, name: string) => {
  const data = await backgroundRequest.post<ApiBackground.Field[] | null>('/kpt/field/search', {
    page,
    page_size,
    name
  });
  return adapter(adapterOfFetchFieldList, data);
};

export const fetchFieldAdd = (params: ApiBackground.Field[]) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/field/add', params);
};

export const fetchFieldEdit = (param: ApiBackground.Field) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/field/edit', param);
};

export const fetchFieldDelete = (fieldId: number) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/field/delete', { id: fieldId });
};
export const fetchEventList = async (page: number, page_size: number, name: string) => {
  const data = await backgroundRequest.post<ApiBackground.Event[] | null>('/kpt/event/search', {
    page,
    page_size,
    name
  });
  return adapter(adapterOfFetchEventList, data);
};

export const fetchEventAdd = (params: ApiBackground.Event) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/event/add', params);
};

export const fetchEventEdit = (param: ApiBackground.Event) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/event/edit', param);
};

export const fetchEventDelete = (eventId: number) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/event/delete', { id: eventId });
};

export const fetchIndicatorsList = async (page: number, page_size: number, name: string) => {
  const data = await backgroundRequest.post<ApiBackground.Indicators[] | null>('/kpt/indicators/search', {
    page,
    page_size,
    name
  });
  return adapter(adapterOfFetchIndicatorsList, data);
};

export const fetchIndicatorsAdd = (params: ApiBackground.Indicators) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/indicators/add', params);
};

export const fetchIndicatorsEdit = (param: ApiBackground.Indicators) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/indicators/edit', param);
};

export const fetchIndicatorsDelete = (fieldId: number) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/indicators/delete', { id: fieldId });
};

export const basicEventColumnName = (eventName: string) => {
  return backgroundRequest.get<ApiBackground.BasicCowField[] | null>(`/basic/table/${eventName}`);
};

export const basicEventList = () => {
  return backgroundRequest.get<ApiBackground.BasicCowField[] | null>(`/basic/event/list`);
};

export const fetchWorkflowList = async (page: number, page_size: number, name: string) => {
  const data = await backgroundRequest.post<ApiBackground.Workflow[] | null>('/kpt/workflow/search', {
    page,
    page_size,
    name
  });
  return adapter(adapterOfFetchWorkflowList, data);
};

export const fetchWorkflowDelete = (workflowId: number) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/workflow/delete', { id: workflowId });
};

export const fetchWorkflowAdd = (params: ApiBackground.Workflow[]) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/workflow/add', params);
};

export const fetchWorkflowEdit = (param: ApiBackground.Workflow) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/kpt/field/edit', param);
};
