import { adapter } from '@/utils';
import {
  adapterOfMqttAuthList,
  adapterOfMqttCategoryEnumList,
  adapterOfMqttCategoryList,
  adapterOfMqttPastureEnumList,
  adapterOfMqttPastureList,
  adapterOfMqttTopicEnumList,
  adapterOfMqttTopicList,
  adapterOfMqttUserList
} from '@/service/api/mqtt.adapter';
import { backgroundRequest } from '../request';

/** 获取用户鉴权列表 */
export const fetchMqttAuthList = async (
  page: number | undefined,
  pageSize: number | undefined,
  params: Mqtt.SearchAuth | null
) => {
  const data = await backgroundRequest.post<Mqtt.Auth[] | null>(
    `/mqtt/auth/list?page=${page}&page_size=${pageSize}`,
    params
  );
  return adapter(adapterOfMqttAuthList, data);
};

/** 删除用户鉴权列表 */
export const mqttAuthDelete = (authId: number) => {
  return backgroundRequest.delete<ApiBoolean.OK | null>(`/mqtt/auth/delete/${authId}`);
};

/** 添加用户鉴权列表 */
export const mqttAuthAdd = (params: Mqtt.Auth) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/auth/add', params);
};

/** 编辑用户鉴权列表 */
export const mqttAuthEdit = (param: Mqtt.Auth) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/auth/edit', param);
};

/** 获取topic列表 */
export const fetchMqttTopicList = async (
  page: number | undefined,
  pageSize: number | undefined,
  topic_name: string
) => {
  const data = await backgroundRequest.post<Mqtt.Topic[] | null>(
    `/mqtt/topic/list?page=${page}&page_size=${pageSize}`,
    {
      topic_name
    }
  );
  return adapter(adapterOfMqttTopicList, data);
};

/** 添加topic */
export const mqttTopicAdd = (params: Mqtt.Topic) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/topic/add', params);
};

/** 编辑topic */
export const mqttTopicEdit = (param: Mqtt.Topic) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/topic/edit', param);
};

export const mqttTopicDelete = (authId: number) => {
  return backgroundRequest.delete<ApiBoolean.OK | null>(`/mqtt/topic/delete/${authId}`);
};

/** 获取用户列表 */
export const fetchMqttUserList = async (page: number, pageSize: number, name: string) => {
  const data = await backgroundRequest.post<Mqtt.User[] | null>(`/mqtt/user/list?page=${page}&page_size=${pageSize}`, {
    name
  });
  return adapter(adapterOfMqttUserList, data);
};

/** 添加User */
export const mqttUserAdd = (params: Mqtt.User) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/user/add', params);
};

/** 编辑User */
export const mqttUserEdit = (param: Mqtt.User) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/user/edit', param);
};

/** 获取牧场列表 */
export const fetchMqttPastureList = async (page: number, pageSize: number, name: string) => {
  const data = await backgroundRequest.post<Mqtt.Pasture[] | null>(
    `/mqtt/pasture/list?page=${page}&page_size=${pageSize}`,
    { name }
  );
  return adapter(adapterOfMqttPastureList, data);
};

/** 添加牧场 */
export const mqttPastureAdd = (params: Mqtt.Pasture) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/pasture/add', params);
};

/** 编辑牧场 */
export const mqttPastureEdit = (param: Mqtt.Pasture) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/pasture/edit', param);
};

export const pastureEnumList = async () => {
  const data = await backgroundRequest.get<Common.OptionWithKey<any>[] | null>('/mqtt/pasture/enum/list');
  return adapter(adapterOfMqttPastureEnumList, data);
};

export const topicEnumList = async (access: number | null) => {
  const data = await backgroundRequest.get<Common.OptionWithKey<any>[] | null>(
    `/mqtt/topic/enum/list?access=${access}`
  );
  return adapter(adapterOfMqttTopicEnumList, data);
};

/** 获取category列表 */
export const fetchMqttCategoryList = async (page: number | undefined, pageSize: number | undefined, name: string) => {
  const data = await backgroundRequest.post<Mqtt.Category[] | null>(
    `/mqtt/topic-category/list?page=${page}&page_size=${pageSize}`,
    { name }
  );
  return adapter(adapterOfMqttCategoryList, data);
};

/** 添加分类 */
export const mqttCategoryAdd = (params: Mqtt.Category) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/topic-category/add', params);
};

/** 编辑分类 */
export const mqttCategoryEdit = (param: Mqtt.Category) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/topic-category/edit', param);
};

export const categoryEnumList = async () => {
  const data = await backgroundRequest.get<Common.OptionWithKey<any>[] | null>('/mqtt/topic-category/enum/list');
  return adapter(adapterOfMqttCategoryEnumList, data);
};
